@@ -2,7 +2,7 @@
 /*
  * gsf-input-memory.c: 
  *
- * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -42,10 +42,16 @@ struct _GsfInputMemory {
 	int fd;
 #endif
 };
-typedef struct {
-	GsfInputClass input_class;
-} GsfInputMemoryClass;
+typedef GsfInputClass GsfInputMemoryClass;
 
+/**
+ * gsf_input_memory_new:
+ * @buf: The input bytes
+ * @length: The length of @buf
+ * @needs_free: Whether you want this memory to be free'd at object destruction
+ *
+ * Returns: A new #GsfInputMemory
+ */
 GsfInputMemory *
 gsf_input_memory_new (guint8 const *buf, gsf_off_t length, gboolean needs_free)
 {
@@ -55,6 +61,13 @@ gsf_input_memory_new (guint8 const *buf, gsf_off_t length, gboolean needs_free)
 	return mem;
 }
 
+/**
+ * gsf_input_memory_new_clone:
+ * @buf: The input bytes
+ * @length: The length of @buf
+ *
+ * Returns: A new #GsfInputMemory
+ */
 GsfInputMemory *
 gsf_input_memory_new_clone (guint8 const *buf, gsf_off_t length)
 {	
@@ -177,7 +190,14 @@ GSF_CLASS (GsfInputMemory, gsf_input_memory,
 #	define MAP_FAILED ((void *)-1)
 #endif
 #endif
-
+     
+/**
+ * gsf_input_mmap_new:
+ * @filename: The file on disk that you want to mmap
+ * @err: A #GError, or optionally %null
+ *
+ * Returns: A new #GsfInputMemory
+ */
 GsfInputMemory *
 gsf_input_mmap_new (char const *filename, GError **err)
 {
@@ -248,7 +268,9 @@ gsf_input_mmap_new (char const *filename, GError **err)
 
 	return mem;
 #else
+#ifdef __GNUC__
 #warning MMAP Unsupported
+#endif
 	(void)filename;
 	if (err != NULL)
 		*err = g_error_new (gsf_input_error (), 0,
