@@ -2,10 +2,10 @@
 /*
  * gsf-msole-impl.h: 
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -78,14 +78,6 @@ G_BEGIN_DECLS
 #define BAT_MAGIC_BAT		0xfffffffd	/* a bat block,    -3 */
 #define BAT_MAGIC_METABAT	0xfffffffc	/* a metabat block -4 */
 
-/* The most common values */
-#define OLE_DEFAULT_THRESHOLD	 0x1000
-#define OLE_DEFAULT_SB_SHIFT	 6
-#define OLE_DEFAULT_SB_SIZE	 (1 << OLE_DEFAULT_SB_SHIFT)
-#define OLE_DEFAULT_BB_SHIFT	 9
-#define OLE_DEFAULT_BB_SIZE	 (1 << OLE_DEFAULT_BB_SHIFT)
-#define OLE_DEFAULT_METABAT_SIZE ((1 << (OLE_DEFAULT_BB_SHIFT - 2)) - 1)
-
 G_END_DECLS
 
 #endif /* GSF_MSOLE_IMPL_H */
