@@ -2,8 +2,8 @@
 /*
  * gsf-output-bzip.c: wrapper to compress to bzipped output
  *
- * Copyright (C) 2003 Dom Lachowicz (cinamod@hotmail.com)
- *               2002 Jon K Hellan (hellan@acm.org)
+ * Copyright (C) 2003-2004 Dom Lachowicz (cinamod@hotmail.com)
+ *               2002-2004 Jon K Hellan (hellan@acm.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -122,8 +122,11 @@ bzip_flush (GsfOutputBzip *bzip)
 				return FALSE;
 		}
 	} while (zret == BZ_FINISH_OK);
-	if (zret != BZ_STREAM_END)
+	if (zret != BZ_STREAM_END) {
+		g_warning ("Unexpected error code %d from bzlib during compression.",
+			   zret);
 		return FALSE;
+	}
 	if (!bzip_output_block (bzip))
 		return FALSE;
 
@@ -144,11 +147,23 @@ gsf_output_bzip_write (GsfOutput *output,
 	bzip->stream.avail_in = num_bytes;
 	
 	while (bzip->stream.avail_in > 0) {
+		int zret;
+
 		if (bzip->stream.avail_out == 0) {
 			if (!bzip_output_block (bzip))
 				return FALSE;
 		}
-		if (BZ2_bzCompress (&bzip->stream, BZ_RUN) != BZ_RUN_OK)
+
+		zret = BZ2_bzCompress (&bzip->stream, BZ_RUN);
+		if (zret != BZ_RUN_OK) {
+			g_warning ("Unexpected error code %d from bzlib during compression.",
+				   zret);
+			return FALSE;
+		}
+	}
+
+	if (bzip->stream.avail_out == 0) {
+		if (!bzip_output_block (bzip))
 			return FALSE;
 	}
 
@@ -243,7 +258,9 @@ gsf_output_bzip_new (GsfOutput *sink, GError **err)
 
 	return bzip;
 #else
+#ifdef __GNUC__
 #warning Building without BZ2 support
+#endif
 	if (err)
 		*err = g_error_new (gsf_input_error (), 0,
 				    "BZ2 support not enabled");
