@@ -2,10 +2,10 @@
 /*
  * gsf-output-gzip.c: wrapper to compress to gzipped output. See rfc1952.
  *
- * Copyright (C) 2002 Jon K Hellan (hellan@acm.org)
+ * Copyright (C) 2002-2004 Jon K Hellan (hellan@acm.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -69,7 +69,7 @@ init_gzip (GsfOutputGZip *gzip, GError **err)
 	}
 	if (!gzip->buf) {
 		gzip->buf_size = Z_BUFSIZE; 
-		gzip->buf = g_malloc (gzip->buf_size);
+		gzip->buf = g_new (guint8, gzip->buf_size);
 	}
 	gzip->stream.next_out  = gzip->buf;
 	gzip->stream.avail_out = gzip->buf_size;
@@ -145,6 +145,11 @@ gsf_output_gzip_finalize (GObject *obj)
 		gzip->sink = NULL;
 	}
 
+	g_free (gzip->buf);
+
+	/* FIXME: check for error?  */
+	deflateEnd (&gzip->stream);
+
 	parent_class = g_type_class_peek (GSF_OUTPUT_TYPE);
 	if (parent_class && parent_class->finalize)
 		parent_class->finalize (obj);
@@ -178,8 +183,11 @@ gzip_flush (GsfOutputGZip *gzip)
 				return FALSE;
 		}
 	} while (zret == Z_OK);
-	if (zret != Z_STREAM_END)
+	if (zret != Z_STREAM_END) {
+		g_warning ("Unexpected error code %d from zlib during compression.",
+			   zret);
 		return FALSE;
+	}
 	if (!gzip_output_block (gzip))
 		return FALSE;
 
@@ -198,17 +206,28 @@ gsf_output_gzip_write (GsfOutput *output,
 	gzip->stream.avail_in = num_bytes;
 	
 	while (gzip->stream.avail_in > 0) {
+		int zret;
 		if (gzip->stream.avail_out == 0) {
 			if (!gzip_output_block (gzip))
 				return FALSE;
 		}
-		if (deflate (&gzip->stream, Z_NO_FLUSH) != Z_OK)
+
+		zret = deflate (&gzip->stream, Z_NO_FLUSH);
+		if (zret != Z_OK) {
+			g_warning ("Unexpected error code %d from zlib during compression.",
+				   zret);
 			return FALSE;
+		}
 	}
 
 	gzip->crc = crc32 (gzip->crc, data, num_bytes);
 	gzip->isize += num_bytes;
 
+	if (gzip->stream.avail_out == 0) {
+		if (!gzip_output_block (gzip))
+			return FALSE;
+	}
+
 	return TRUE;
 }
 
