@@ -2,7 +2,7 @@
 /*
  * gsf-output-stdio.c: stdio based output
  *
- * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -160,14 +160,15 @@ gsf_output_stdio_new (char const *filename, GError **err)
 {
 	GsfOutputStdio *stdio;
 	FILE *file = NULL;
-	char *dirname, *temp_filename = NULL;
+	char *dirname = NULL;
+	char *temp_filename = NULL;
 	char *real_filename = follow_symlinks (filename, err);
 	int fd;
 	mode_t saved_umask;
 	struct stat st;
-	
+
 	if (real_filename == NULL)
-		return NULL;
+		goto failure;
 
 	/* Get the directory in which the real filename lives */
 	dirname = g_path_get_dirname (real_filename);
@@ -210,7 +211,6 @@ gsf_output_stdio_new (char const *filename, GError **err)
 	 * implementations of mkstemp() use permissions 0666 and we want 0600.
 	 */
 	temp_filename = g_build_filename (dirname, ".gsf-save-XXXXXX", NULL);
-	g_free (dirname);
 	/* Oh, joy.  What about threads?  --MW */
 	saved_umask = umask (0077);
 	fd = g_mkstemp (temp_filename); /* this modifies temp_filename to the used name */
@@ -231,11 +231,14 @@ gsf_output_stdio_new (char const *filename, GError **err)
 	stdio->temp_filename = temp_filename;
 	gsf_output_set_name (GSF_OUTPUT (stdio), filename);
 
+	g_free (dirname);
+
 	return stdio;
 
 failure :
 	g_free (temp_filename);
 	g_free (real_filename);
+	g_free (dirname);
 	return NULL;
 }
 
@@ -252,7 +255,8 @@ gsf_output_stdio_close (GsfOutput *output)
 	res = (0 == fclose (stdio->file));
 	stdio->file = NULL;
 	if (!res) {
-		gsf_output_set_error (output, errno, " ");
+		gsf_output_set_error (output, errno,
+				      "Failed to close temporary file.");
 		unlink (stdio->temp_filename);
 		return FALSE;
 	}
@@ -367,9 +371,9 @@ gsf_output_stdio_write (GsfOutput *output,
 	while (remaining > 0) {
 		written = fwrite (buffer + (num_bytes - remaining), 1, 
 				  remaining, stdio->file);
-		if ((written < remaining) && ferror (stdio->file) != 0) {
+		if ((written < remaining) && ferror (stdio->file) != 0)
 			return gsf_output_set_error (output, errno, g_strerror (errno));
-		}
+
 		remaining -= written;
 	}
 	return TRUE;
@@ -379,9 +383,7 @@ static gboolean
 gsf_output_stdio_vprintf (GsfOutput *output, char const *fmt, va_list args)
 {
 	GsfOutputStdio *stdio = (GsfOutputStdio *)output;
-	int res = vfprintf (stdio->file, fmt, args);
-
-	return (res >= 0);
+	return vfprintf (stdio->file, fmt, args) >= 0;
 }
 
 static void
