@@ -2,10 +2,10 @@
 /*
  * test-input1.c:
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -35,7 +35,7 @@ test (int argc, char *argv[])
 		return 1;
 	}
 
-	input = gsf_input_stdio_new (argv[1], &err);
+	input = GSF_INPUT (gsf_input_stdio_new (argv[1], &err));
 	if (input == NULL) {
 
 		g_return_val_if_fail (err != NULL, 1);
