@@ -25,9 +25,12 @@
 #include <gsf/gsf-infile-msole.h>
 
 #include <stdio.h>
+#include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
 
+static gboolean dump_as_hex = FALSE;
+
 static void
 ls_R (GsfInput *input)
 {
@@ -107,7 +110,7 @@ test (int argc, char *argv[])
 			    gsf_infile_num_children (GSF_INFILE (ptr)) >= 0)
 				ls_R (ptr); /* unrefs infile */
 			else {
-				gsf_input_dump (GSF_INPUT (ptr));
+				gsf_input_dump (GSF_INPUT (ptr), dump_as_hex);
 				g_object_unref (G_OBJECT (ptr));
 			}
 		}
@@ -123,10 +126,16 @@ main (int argc, char *argv[])
 	int res;
 
 	if (argc < 2) {
-		fprintf (stderr, "%s : file stream stream ...\n", argv [0]);
+		fprintf (stderr, "%s : file [--hex] stream stream ...\n", argv [0]);
 		return 1;
 	}
 
+	if (argv[1] != NULL && 0 == strcmp (argv[1], "--hex")) {
+		dump_as_hex = TRUE;
+		argv++;
+		argc--;
+	}
+
 	gsf_init ();
 	res = test (argc, argv);
 	gsf_shutdown ();
